import { userDepsImportMap, userDepsImportPath, } from './userDepsShared.js';
export function userDepsTemplate({ globalImports, fixturePaths, decoratorPaths, rendererConfig, rootDir, relativeToDir, }) {
    const fixtures = userDepsImportMap(fixturePaths, rootDir, relativeToDir);
    const fixtureKeys = Object.keys(fixtures);
    const decorators = userDepsImportMap(decoratorPaths, rootDir, relativeToDir);
    const decoratorKeys = Object.keys(decorators);
    return `
// This file is automatically generated by Cosmos. Add it to .gitignore and
// only edit if you know what you're doing.

// Keeping global imports here is superior to making them bundle entry points
// because this way they become hot-reloadable.
${globalImports
        .map(p => `import '${userDepsImportPath(p, relativeToDir)}';`)
        .join(`\n`)}

${fixtureKeys
        .map((k, i) => `import fixture${i} from '${fixtures[k]}';`)
        .join(`\n`)}

${decoratorKeys
        .map((k, i) => `import decorator${i} from '${decorators[k]}';`)
        .join(`\n`)}

export const rendererConfig = ${JSON.stringify(rendererConfig, null, 2)};

const fixtures = {
${fixtureKeys
        .map((k, i) => ` '${k}': { module: { default: fixture${i} } }`)
        .join(`,\n`)}
};

const decorators = {
${decoratorKeys
        .map((k, i) => ` '${k}': { module: { default: decorator${i} } }`)
        .join(`,\n`)}
};

export const moduleWrappers = {
  lazy: false,
  fixtures,
  decorators,
};
`.trimStart();
}
